==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsAdHocFilteringOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsAdHocFilteringOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsAdHocFilteringOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsAdHocFilteringOptionArgsBuilder internal constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("vtvresbevhvrkyyk")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("sjhckqbbdrdawjnd")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsAdHocFilteringOptionArgs =
        DashboardDashboardPublishOptionsAdHocFilteringOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsAdHocFilteringOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsAdHocFilteringOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsAdHocFilteringOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsAdHocFilteringOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsAdHocFilteringOptionArgsBuilder internal constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("eihljttcbpumjiwm")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("flquqotnnqultirr")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsAdHocFilteringOptionArgs =
        DashboardDashboardPublishOptionsAdHocFilteringOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}
